@@ -155,8 +155,7 @@ class RedisCustomer(object):
 
                         self._threadpool.submit(self._consuming_exception_retry, message)
                 else:
-                    if self.middleware != MiddlewareEum.REDIS:
-                        time.sleep(0.5)
+                    time.sleep(0.3)
             except:
                 logger.error(traceback.format_exc())
                 time.sleep(0.5)
@@ -375,7 +374,11 @@ class RedisPublish(object):
         return self._redis_quenen.qsize()
 
 
-def task_deco(queue_name, *consumer_args, **consumer_init_kwargs):
+def task_deco(queue_name, process_num=1, threads_num=50,
+              max_retry_times=3, qps=0,
+              middleware=MiddlewareEum.REDIS,
+              specify_threadpool=None, customer_type='thread', fliter_rep=False, ack=False, *consumer_args,
+              **consumer_init_kwargs):
     """
     support by ydf
     装饰器方式添加任务，如果有人过于喜欢装饰器方式，例如celery 装饰器方式的任务注册，觉得黑科技，那就可以使用这个装饰器。此种方式不利于ide代码自动补全不推荐。
@@ -399,7 +402,10 @@ def task_deco(queue_name, *consumer_args, **consumer_init_kwargs):
     """
 
     def _deco(func):
-        cs = RedisCustomer(queue_name, consuming_function=func, *consumer_args, **consumer_init_kwargs)
+        cs = RedisCustomer(queue_name, process_num=process_num, threads_num=threads_num, middleware=middleware, qps=qps,
+                           consuming_function=func, specify_threadpool=specify_threadpool, customer_type=customer_type,
+                           fliter_rep=fliter_rep, ack=ack, max_retry_times=max_retry_times,
+                           *consumer_args, **consumer_init_kwargs)
         if 'consuming_function' in consumer_init_kwargs:
             consumer_init_kwargs.pop('consuming_function')
         func.consumer = cs
